=======
MooTdx 通达信数据转换程序
=======


.. image:: https://img.shields.io/pypi/v/mootdx.svg
        :target: https://pypi.python.org/pypi/mootdx

.. image:: https://img.shields.io/travis/bopo/mootdx.svg
        :target: https://travis-ci.org/bopo/mootdx

.. image:: https://readthedocs.org/projects/mootdx/badge/?version=latest
        :target: https://mootdx.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/bopo/mootdx/shield.svg
     :target: https://pyup.io/repos/github/bopo/mootdx/
     :alt: Updates



* 开源协议: MIT license
* 在线文档: https://mootdx.readthedocs.io.


功能
--------

* 本程序不在支持 python 2 版本.
* 通达信客户端文件转换
* 通达信在线行情下载

Credits
---------


